/* budgiemenuapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_BUDGIE_MENU_BUDGIEMENUAPPLET_H__
#define __SRC_PANEL_APPLETS_BUDGIE_MENU_BUDGIEMENUAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "budgie-appindexer.h"
#include "budgie-private.h"
#include <gee.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define USER_ICON "user-info"

#define TYPE_BUDGIE_MENU (budgie_menu_get_type ())
#define BUDGIE_MENU(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUDGIE_MENU, BudgieMenu))
#define BUDGIE_MENU_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUDGIE_MENU, BudgieMenuClass))
#define IS_BUDGIE_MENU(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUDGIE_MENU))
#define IS_BUDGIE_MENU_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUDGIE_MENU))
#define BUDGIE_MENU_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUDGIE_MENU, BudgieMenuClass))

typedef struct _BudgieMenu BudgieMenu;
typedef struct _BudgieMenuClass BudgieMenuClass;
typedef struct _BudgieMenuPrivate BudgieMenuPrivate;

#define TYPE_BUDGIE_MENU_SETTINGS (budgie_menu_settings_get_type ())
#define BUDGIE_MENU_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUDGIE_MENU_SETTINGS, BudgieMenuSettings))
#define BUDGIE_MENU_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUDGIE_MENU_SETTINGS, BudgieMenuSettingsClass))
#define IS_BUDGIE_MENU_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUDGIE_MENU_SETTINGS))
#define IS_BUDGIE_MENU_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUDGIE_MENU_SETTINGS))
#define BUDGIE_MENU_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUDGIE_MENU_SETTINGS, BudgieMenuSettingsClass))

typedef struct _BudgieMenuSettings BudgieMenuSettings;
typedef struct _BudgieMenuSettingsClass BudgieMenuSettingsClass;
typedef struct _BudgieMenuSettingsPrivate BudgieMenuSettingsPrivate;

#define TYPE_BUDGIE_MENU_APPLET (budgie_menu_applet_get_type ())
#define BUDGIE_MENU_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUDGIE_MENU_APPLET, BudgieMenuApplet))
#define BUDGIE_MENU_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUDGIE_MENU_APPLET, BudgieMenuAppletClass))
#define IS_BUDGIE_MENU_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUDGIE_MENU_APPLET))
#define IS_BUDGIE_MENU_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUDGIE_MENU_APPLET))
#define BUDGIE_MENU_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUDGIE_MENU_APPLET, BudgieMenuAppletClass))

typedef struct _BudgieMenuApplet BudgieMenuApplet;
typedef struct _BudgieMenuAppletClass BudgieMenuAppletClass;
typedef struct _BudgieMenuAppletPrivate BudgieMenuAppletPrivate;

#define TYPE_BUDGIE_MENU_WINDOW (budgie_menu_window_get_type ())
#define BUDGIE_MENU_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUDGIE_MENU_WINDOW, BudgieMenuWindow))
#define BUDGIE_MENU_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUDGIE_MENU_WINDOW, BudgieMenuWindowClass))
#define IS_BUDGIE_MENU_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUDGIE_MENU_WINDOW))
#define IS_BUDGIE_MENU_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUDGIE_MENU_WINDOW))
#define BUDGIE_MENU_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUDGIE_MENU_WINDOW, BudgieMenuWindowClass))

typedef struct _BudgieMenuWindow BudgieMenuWindow;
typedef struct _BudgieMenuWindowClass BudgieMenuWindowClass;

#define TYPE_CATEGORY_BUTTON (category_button_get_type ())
#define CATEGORY_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CATEGORY_BUTTON, CategoryButton))
#define CATEGORY_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CATEGORY_BUTTON, CategoryButtonClass))
#define IS_CATEGORY_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CATEGORY_BUTTON))
#define IS_CATEGORY_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CATEGORY_BUTTON))
#define CATEGORY_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CATEGORY_BUTTON, CategoryButtonClass))

typedef struct _CategoryButton CategoryButton;
typedef struct _CategoryButtonClass CategoryButtonClass;
typedef struct _CategoryButtonPrivate CategoryButtonPrivate;

#define TYPE_MENU_BUTTON (menu_button_get_type ())
#define MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MENU_BUTTON, MenuButton))
#define MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MENU_BUTTON, MenuButtonClass))
#define IS_MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MENU_BUTTON))
#define IS_MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MENU_BUTTON))
#define MENU_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MENU_BUTTON, MenuButtonClass))

typedef struct _MenuButton MenuButton;
typedef struct _MenuButtonClass MenuButtonClass;
typedef struct _MenuButtonPrivate MenuButtonPrivate;
typedef struct _BudgieMenuWindowPrivate BudgieMenuWindowPrivate;

#define TYPE_APPLICATION_VIEW (application_view_get_type ())
#define APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION_VIEW, ApplicationView))
#define APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION_VIEW, ApplicationViewClass))
#define IS_APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION_VIEW))
#define IS_APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION_VIEW))
#define APPLICATION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION_VIEW, ApplicationViewClass))

typedef struct _ApplicationView ApplicationView;
typedef struct _ApplicationViewClass ApplicationViewClass;

#define TYPE_ICON_CHOOSER (icon_chooser_get_type ())
#define ICON_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_CHOOSER, IconChooser))
#define ICON_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_CHOOSER, IconChooserClass))
#define IS_ICON_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_CHOOSER))
#define IS_ICON_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_CHOOSER))
#define ICON_CHOOSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_CHOOSER, IconChooserClass))

typedef struct _IconChooser IconChooser;
typedef struct _IconChooserClass IconChooserClass;
typedef struct _IconChooserPrivate IconChooserPrivate;

#define TYPE_XDG_DIR_TRACKER_REMOTE (xdg_dir_tracker_remote_get_type ())
#define XDG_DIR_TRACKER_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_XDG_DIR_TRACKER_REMOTE, XDGDirTrackerRemote))
#define IS_XDG_DIR_TRACKER_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_XDG_DIR_TRACKER_REMOTE))
#define XDG_DIR_TRACKER_REMOTE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_XDG_DIR_TRACKER_REMOTE, XDGDirTrackerRemoteIface))

typedef struct _XDGDirTrackerRemote XDGDirTrackerRemote;
typedef struct _XDGDirTrackerRemoteIface XDGDirTrackerRemoteIface;

#define TYPE_XDG_DIR_TRACKER_REMOTE_PROXY (xdg_dir_tracker_remote_proxy_get_type ())

#define TYPE_OVERLAY_MENUS (overlay_menus_get_type ())
#define OVERLAY_MENUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OVERLAY_MENUS, OverlayMenus))
#define OVERLAY_MENUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OVERLAY_MENUS, OverlayMenusClass))
#define IS_OVERLAY_MENUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OVERLAY_MENUS))
#define IS_OVERLAY_MENUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OVERLAY_MENUS))
#define OVERLAY_MENUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OVERLAY_MENUS, OverlayMenusClass))

typedef struct _OverlayMenus OverlayMenus;
typedef struct _OverlayMenusClass OverlayMenusClass;
typedef struct _OverlayMenusPrivate OverlayMenusPrivate;

#define TYPE_USER_BUTTON (user_button_get_type ())
#define USER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_USER_BUTTON, UserButton))
#define USER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_USER_BUTTON, UserButtonClass))
#define IS_USER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_USER_BUTTON))
#define IS_USER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_USER_BUTTON))
#define USER_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_USER_BUTTON, UserButtonClass))

typedef struct _UserButton UserButton;
typedef struct _UserButtonClass UserButtonClass;
typedef struct _UserButtonPrivate UserButtonPrivate;

#define TYPE_MENU_ITEM (menu_item_get_type ())
#define MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MENU_ITEM, MenuItem))
#define MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MENU_ITEM, MenuItemClass))
#define IS_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MENU_ITEM))
#define IS_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MENU_ITEM))
#define MENU_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MENU_ITEM, MenuItemClass))

typedef struct _MenuItem MenuItem;
typedef struct _MenuItemClass MenuItemClass;
typedef struct _MenuItemPrivate MenuItemPrivate;
typedef struct _ApplicationViewPrivate ApplicationViewPrivate;

#define TYPE_APPLICATION_LIST_VIEW (application_list_view_get_type ())
#define APPLICATION_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION_LIST_VIEW, ApplicationListView))
#define APPLICATION_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION_LIST_VIEW, ApplicationListViewClass))
#define IS_APPLICATION_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION_LIST_VIEW))
#define IS_APPLICATION_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION_LIST_VIEW))
#define APPLICATION_LIST_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION_LIST_VIEW, ApplicationListViewClass))

typedef struct _ApplicationListView ApplicationListView;
typedef struct _ApplicationListViewClass ApplicationListViewClass;
typedef struct _ApplicationListViewPrivate ApplicationListViewPrivate;

struct _BudgieMenu {
	PeasExtensionBase parent_instance;
	BudgieMenuPrivate * priv;
};

struct _BudgieMenuClass {
	PeasExtensionBaseClass parent_class;
};

struct _BudgieMenuSettings {
	GtkGrid parent_instance;
	BudgieMenuSettingsPrivate * priv;
};

struct _BudgieMenuSettingsClass {
	GtkGridClass parent_class;
};

struct _BudgieMenuApplet {
	BudgieApplet parent_instance;
	BudgieMenuAppletPrivate * priv;
	GtkToggleButton* widget;
	BudgieMenuWindow* popover;
	GSettings* settings;
};

struct _BudgieMenuAppletClass {
	BudgieAppletClass parent_class;
};

struct _CategoryButton {
	GtkRadioButton parent_instance;
	CategoryButtonPrivate * priv;
};

struct _CategoryButtonClass {
	GtkRadioButtonClass parent_class;
};

struct _MenuButton {
	GtkButton parent_instance;
	MenuButtonPrivate * priv;
};

struct _MenuButtonClass {
	GtkButtonClass parent_class;
};

struct _BudgieMenuWindow {
	GtkPopover parent_instance;
	BudgieMenuWindowPrivate * priv;
	GtkBox* main_layout;
	GtkSearchEntry* search_entry;
	ApplicationView* view;
};

struct _BudgieMenuWindowClass {
	GtkPopoverClass parent_class;
};

struct _IconChooser {
	GtkFileChooserDialog parent_instance;
	IconChooserPrivate * priv;
};

struct _IconChooserClass {
	GtkFileChooserDialogClass parent_class;
};

struct _XDGDirTrackerRemoteIface {
	GTypeInterface parent_iface;
	GUserDirectory* (*get_dirs) (XDGDirTrackerRemote* self, gint* result_length1, GError** error);
};

struct _OverlayMenus {
	GtkRevealer parent_instance;
	OverlayMenusPrivate * priv;
};

struct _OverlayMenusClass {
	GtkRevealerClass parent_class;
};

struct _UserButton {
	GtkButton parent_instance;
	UserButtonPrivate * priv;
};

struct _UserButtonClass {
	GtkButtonClass parent_class;
};

struct _MenuItem {
	GtkButton parent_instance;
	MenuItemPrivate * priv;
};

struct _MenuItemClass {
	GtkButtonClass parent_class;
};

struct _ApplicationView {
	GtkBox parent_instance;
	ApplicationViewPrivate * priv;
	BudgieRelevancyService* relevancy_service;
};

struct _ApplicationViewClass {
	GtkBoxClass parent_class;
	void (*on_search_entry_activated) (ApplicationView* self);
	void (*on_show) (ApplicationView* self);
	void (*refresh) (ApplicationView* self, BudgieAppIndex* app_tracker);
	void (*invalidate) (ApplicationView* self);
};

struct _ApplicationListView {
	ApplicationView parent_instance;
	ApplicationListViewPrivate * priv;
};

struct _ApplicationListViewClass {
	ApplicationViewClass parent_class;
};

GType budgie_menu_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_menu_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieMenu, g_object_unref)
VALA_EXTERN BudgieMenu* budgie_menu_new (void);
VALA_EXTERN BudgieMenu* budgie_menu_construct (GType object_type);
GType budgie_menu_settings_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_menu_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieMenuSettings, g_object_unref)
VALA_EXTERN BudgieMenuSettings* budgie_menu_settings_new (GSettings* settings);
VALA_EXTERN BudgieMenuSettings* budgie_menu_settings_construct (GType object_type,
                                                    GSettings* settings);
GType budgie_menu_applet_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_menu_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieMenuApplet, g_object_unref)
GType budgie_menu_window_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_menu_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieMenuWindow, g_object_unref)
VALA_EXTERN BudgieMenuApplet* budgie_menu_applet_new (const gchar* uuid);
VALA_EXTERN BudgieMenuApplet* budgie_menu_applet_construct (GType object_type,
                                                const gchar* uuid);
VALA_EXTERN void budgie_menu_applet_on_settings_changed (BudgieMenuApplet* self,
                                             const gchar* key);
VALA_EXTERN const gchar* budgie_menu_applet_get_uuid (BudgieMenuApplet* self);
VALA_EXTERN void budgie_menu_applet_set_uuid (BudgieMenuApplet* self,
                                  const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);
GType category_button_register_type (GTypeModule * module);
VALA_EXTERN GType category_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CategoryButton, g_object_unref)
VALA_EXTERN CategoryButton* category_button_new (BudgieCategory* category);
VALA_EXTERN CategoryButton* category_button_construct (GType object_type,
                                           BudgieCategory* category);
VALA_EXTERN BudgieCategory* category_button_get_category (CategoryButton* self);
GType menu_button_register_type (GTypeModule * module);
VALA_EXTERN GType menu_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MenuButton, g_object_unref)
VALA_EXTERN MenuButton* menu_button_new (BudgieApplication* app,
                             BudgieCategory* category,
                             gint icon_size);
VALA_EXTERN MenuButton* menu_button_construct (GType object_type,
                                   BudgieApplication* app,
                                   BudgieCategory* category,
                                   gint icon_size);
VALA_EXTERN gboolean menu_button_is_control_center_panel (MenuButton* self);
VALA_EXTERN BudgieApplication* menu_button_get_app (MenuButton* self);
VALA_EXTERN BudgieCategory* menu_button_get_category (MenuButton* self);
GType application_view_register_type (GTypeModule * module);
VALA_EXTERN GType application_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ApplicationView, g_object_unref)
VALA_EXTERN BudgieMenuWindow* budgie_menu_window_new (GSettings* settings,
                                          GtkWidget* leparent);
VALA_EXTERN BudgieMenuWindow* budgie_menu_window_construct (GType object_type,
                                                GSettings* settings,
                                                GtkWidget* leparent);
VALA_EXTERN void budgie_menu_window_open_desktop_entry (BudgieMenuWindow* self,
                                            const gchar* name);
VALA_EXTERN void budgie_menu_window_refresh (BudgieMenuWindow* self,
                                 BudgieAppIndex* app_index,
                                 gboolean now);
VALA_EXTERN void budgie_menu_window_reset (BudgieMenuWindow* self,
                               gboolean clear_search);
GType icon_chooser_register_type (GTypeModule * module);
VALA_EXTERN GType icon_chooser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconChooser, g_object_unref)
VALA_EXTERN IconChooser* icon_chooser_new (GtkWindow* parent);
VALA_EXTERN IconChooser* icon_chooser_construct (GType object_type,
                                     GtkWindow* parent);
VALA_EXTERN gchar* icon_chooser_run (IconChooser* self);
VALA_EXTERN GType xdg_dir_tracker_remote_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void xdg_dir_tracker_remote_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint xdg_dir_tracker_remote_register_object (void* object,
                                              GDBusConnection* connection,
                                              const gchar* path,
                                              GError** error);
GType xdg_dir_tracker_remote_register_type (GTypeModule * module);
VALA_EXTERN GType xdg_dir_tracker_remote_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XDGDirTrackerRemote, g_object_unref)
VALA_EXTERN GUserDirectory* xdg_dir_tracker_remote_get_dirs (XDGDirTrackerRemote* self,
                                                 gint* result_length1,
                                                 GError** error);
GType overlay_menus_register_type (GTypeModule * module);
VALA_EXTERN GType overlay_menus_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OverlayMenus, g_object_unref)
VALA_EXTERN OverlayMenus* overlay_menus_new (void);
VALA_EXTERN OverlayMenus* overlay_menus_construct (GType object_type);
VALA_EXTERN void overlay_menus_set_visible_menu (OverlayMenus* self,
                                     const gchar* vis);
GType user_button_register_type (GTypeModule * module);
VALA_EXTERN GType user_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UserButton, g_object_unref)
VALA_EXTERN UserButton* user_button_new (void);
VALA_EXTERN UserButton* user_button_construct (GType object_type);
GType menu_item_register_type (GTypeModule * module);
VALA_EXTERN GType menu_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MenuItem, g_object_unref)
VALA_EXTERN MenuItem* menu_item_new (const gchar* label_text,
                         const gchar* image_source);
VALA_EXTERN MenuItem* menu_item_construct (GType object_type,
                               const gchar* label_text,
                               const gchar* image_source);
VALA_EXTERN void menu_item_set_image (MenuItem* self,
                          const gchar* source);
VALA_EXTERN void menu_item_set_label (MenuItem* self,
                          const gchar* text);
VALA_EXTERN const gchar* menu_item_get_image_source (MenuItem* self);
VALA_EXTERN void menu_item_set_image_source (MenuItem* self,
                                 const gchar* value);
VALA_EXTERN const gchar* menu_item_get_label_text (MenuItem* self);
VALA_EXTERN void menu_item_set_label_text (MenuItem* self,
                               const gchar* value);
GType application_list_view_register_type (GTypeModule * module);
VALA_EXTERN GType application_list_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ApplicationListView, g_object_unref)
VALA_EXTERN ApplicationListView* application_list_view_new (GSettings* settings);
VALA_EXTERN ApplicationListView* application_list_view_construct (GType object_type,
                                                      GSettings* settings);
VALA_EXTERN GSettings* application_list_view_get_settings (ApplicationListView* self);
VALA_EXTERN void application_view_on_search_entry_activated (ApplicationView* self);
VALA_EXTERN void application_view_on_show (ApplicationView* self);
VALA_EXTERN void application_view_refresh (ApplicationView* self,
                               BudgieAppIndex* app_tracker);
VALA_EXTERN void application_view_invalidate (ApplicationView* self);
VALA_EXTERN void application_view_queue_refresh (ApplicationView* self,
                                     BudgieAppIndex* app_tracker,
                                     gint seconds);
VALA_EXTERN void application_view_search_changed (ApplicationView* self,
                                      const gchar* search_term);
VALA_EXTERN gboolean application_view_is_item_dupe (ApplicationView* self,
                                        MenuButton* button);
VALA_EXTERN ApplicationView* application_view_construct (GType object_type);
VALA_EXTERN GHashTable* application_view_get_application_buttons (ApplicationView* self);
VALA_EXTERN void application_view_set_application_buttons (ApplicationView* self,
                                               GHashTable* value);
VALA_EXTERN GeeArrayList* application_view_get_control_center_buttons (ApplicationView* self);
VALA_EXTERN void application_view_set_control_center_buttons (ApplicationView* self,
                                                  GeeArrayList* value);
VALA_EXTERN const gchar* application_view_get_search_term (ApplicationView* self);
VALA_EXTERN void application_view_set_search_term (ApplicationView* self,
                                       const gchar* value);
VALA_EXTERN gint application_view_get_icon_size (ApplicationView* self);
VALA_EXTERN void application_view_set_icon_size (ApplicationView* self,
                                     gint value);

G_END_DECLS

#endif
